package com.jeeplus.test.garbageClearance.service;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ArrayUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.extra.spring.SpringUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jeeplus.common.redis.RedisUtils;
import com.jeeplus.core.query.QueryWrapperGenerator;
import com.jeeplus.security.jwt.TokenProvider;
import com.jeeplus.sys.constant.CacheNames;
import com.jeeplus.sys.domain.User;
import com.jeeplus.sys.service.dto.UserDTO;
import com.jeeplus.sys.utils.UserUtils;
import com.jeeplus.test.garbageClearance.domain.LookOver;
import com.jeeplus.test.garbageClearance.mapper.LookOverMapper;
import com.jeeplus.test.oss.domain.WorkAttachmentInfo;
import com.jeeplus.test.oss.service.OssService;
import org.springframework.beans.factory.annotation.Autowired;
import com.jeeplus.test.garbageClearance.service.DTO.LookOverDTO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

import java.util.List;
import java.util.stream.Collectors;

/**
 * @author 王强
 * @version 1.0
 * @date 2024-08-29 10:51
 */
@Service
@Transactional
public class LookOverService extends ServiceImpl<LookOverMapper, LookOver> {

    @Autowired
    private OssService ossService;

    public String getMaxNo() {
        // 创建查询条件构造器
        QueryWrapper<LookOver> queryWrapper = new QueryWrapper<>();

        // 按no字段降序排列
        queryWrapper.select("MAX(no) as no");

        // 只获取第一条记录
        LookOver lookOver = baseMapper.selectOne(queryWrapper);

        // 返回最大的no值
        return lookOver != null ? lookOver.getNo() : null;
    }

    public UserDTO getUserInfoByOffId(String officeId) {
        return baseMapper.getUserInfoByOffId(officeId);
    }

    /**
     * 根据id获取巡视工单信息
     * @param id
     * @return
     */
    public LookOver selectByID(String id) {
        LookOver lookOver = baseMapper.selectByID(id);
        List<WorkAttachmentInfo> files = baseMapper.getByAttachmentId(id);

        if (null != files && files.size()>0) {
            files.forEach(fi->{
                String fileTemporaryLookUrl = ossService.getFileTemporaryLookUrl(fi.getUrl());
                fi.setUrl(fileTemporaryLookUrl);
            });

            lookOver.setFileList1(files);
        }

        // 根据id 从work_attachment 表中获取图片信息
        return lookOver;
    }



    /**
     * 查询无报告项目及老项目列表信息
     * @param page
     * @param lookOver
     * @return
     * @throws Exception
     */
    public IPage<LookOver> getNotDisposeList(Page<LookOverDTO> page, LookOverDTO lookOver) throws Exception{
        UserDTO userDTO = UserUtils.getCurrentUserDTO();
        QueryWrapper<LookOverDTO> queryWrapper = QueryWrapperGenerator.buildQueryCondition ( lookOver, LookOverDTO.class );
        queryWrapper.eq("a.del_flag","0");
        queryWrapper.eq("a.processing_unit",userDTO.getOfficeDTO().getId());
        if(StringUtils.isNotBlank(lookOver.getStatus())){
            queryWrapper.eq("a.status",lookOver.getStatus());
        }
        IPage<LookOver> pageList = baseMapper.findPage(page, queryWrapper);
        for (LookOver record : pageList.getRecords()) {
            if(StringUtils.isNotBlank(record.getNo())){
                String no = "XS-J" + record.getNo();
                record.setNo(no);
            }
        }
        return pageList;
    }
}
